@@ -12,11 +12,11 @@ from tensorflow.keras.models import Model as TF_Model
 
 from aibro.tools.auth import check_authentication
 from aibro.tools.service.api_service import aibro_client
-from aibro.tools.utils import _deserialize_model_data
 from aibro.tools.utils import datetime_to_timestamp_ms
 from aibro.tools.utils import hybridmethod
 from aibro.tools.utils import ModelAndDataset
 from aibro.tools.utils import unpack_base64_encoded_pickle
+from aibro.tools.utils_training import deserialize_model_data
 from aibro.training import _get_model_from_file
 from aibro.training import Training
 
@@ -363,7 +363,7 @@ def _replay_job(
     job = resp.json()["job"]
     model_and_data = resp.json()["model_and_data"]
     data = ModelAndDataset(**model_and_data)
-    data_decode = _deserialize_model_data(data)
+    data_decode = deserialize_model_data(data)
     print("[REPLAYING]: cloning a new job to start replay.")
     description = description if description != "" else job["description"]
     job_id, result_model, history = Training.online_fit(  # type: ignore
