@@ -15,15 +15,15 @@ def assert_data_type(data, data_name):
         size = get_data_size_mb(data)
         assert (
             size <= INPUT_DATA_SIZE_LIMIT_MB
-        ), f"ERROR: {data_name} has size {size} MB exceeding maximum limit of 1G"
+        ), f"{data_name} has size {size} MB exceeding maximum limit of 1G"
     else:
-        raise Exception(f"ERROR: {data_name} must be numpy or tensor type")
+        raise Exception(f"{data_name} must be numpy type")
     return data
 
 
 def assert_batch_size_type(batch_size):
-    assert type(batch_size) == int, "ERROR: Incorrect type for batch_size (int)"
+    assert type(batch_size) == int, "Incorrect type for batch_size (int)"
 
 
 def assert_epochs_type(epochs):
-    assert type(epochs) == int, "ERROR: Incorrect type for epochs (int)"
+    assert type(epochs) == int, "Incorrect type for epochs (int)"
